[Libreoffice-commits] core.git: svtools/source

Thomas Arnhold thomas at arnhold.org
Thu Oct 10 10:59:17 PDT 2013


 svtools/source/svhtml/parhtml.cxx |    6 ++----
 1 file changed, 2 insertions(+), 4 deletions(-)

New commits:
commit 700883b34ebcdb77f398b4423f358bdf4648a853
Author: Thomas Arnhold <thomas at arnhold.org>
Date:   Thu Oct 10 16:34:29 2013 +0200

    html: Options need to be lowercase, too
    
    Because the lookup table (include/svtools/htmlkywd.hxx) is now lowercase.
    
    Change-Id: Ica0606eb1546f74d2b651a70adee8117c956d4e2
    Reviewed-on: https://gerrit.libreoffice.org/6193
    Reviewed-by: Thomas Arnhold <thomas at arnhold.org>
    Tested-by: Thomas Arnhold <thomas at arnhold.org>

diff --git a/svtools/source/svhtml/parhtml.cxx b/svtools/source/svhtml/parhtml.cxx
index 474fd20..b729259 100644
--- a/svtools/source/svhtml/parhtml.cxx
+++ b/svtools/source/svhtml/parhtml.cxx
@@ -1470,10 +1470,8 @@ const HTMLOptions& HTMLParser::GetOptions( sal_uInt16 *pNoConvertToken )
 
             OUString sName( aToken.copy( nStt, nPos-nStt ) );
 
-            // PlugIns require original token name. Convert to upper case only for searching.
-            OUString sNameUpperCase( sName.toAsciiUpperCase() );
-
-            nToken = GetHTMLOption( sNameUpperCase ); // Name is ready
+            // PlugIns require original token name. Convert to lower case only for searching.
+            nToken = GetHTMLOption( sName.toAsciiLowerCase() ); // Name is ready
             DBG_ASSERTWARNING( nToken!=HTML_O_UNKNOWN,
                         "GetOption: unknown HTML option" );
             bool bStripCRLF = (nToken < HTML_OPTION_SCRIPT_START ||


More information about the Libreoffice-commits mailing list